import pathlib


def nearest(pattern):
    """Search for a file in the current working directory and its 
    parent directories (traversed upwards).

    If multiple files match `pattern` in a single directory,
    only one is returned (essentially at random).

    :param pattern: a glob-style pattern
    :return: nearest file that matches `pattern`
    """
    search = pathlib.Path.cwd().resolve()

    while search.parent != search:
        for match in search.glob(pattern):
            return match
        search = search.parent

    # Don't forget the root directory.
    for match in search.glob(pattern):
        return match

    raise FileNotFoundError(pattern)
